import { Aff } from './aff';
import { Sequence } from 'gensequence';
import { WordInfo } from './types';
export { WordInfo } from './types';
export interface HunspellSrcData {
    aff: Aff;
    dic: string[];
}
export declare class IterableHunspellReader implements Iterable<string> {
    readonly src: HunspellSrcData;
    readonly aff: Aff;
    constructor(src: HunspellSrcData);
    get dic(): string[];
    set maxDepth(value: number);
    get maxDepth(): number;
    /**
     * @internal
     */
    dicWordsSeq(): Sequence<WordInfo>;
    /**
     * iterates through the root words of the dictionary
     */
    iterateRootWords(): Iterable<string>;
    iterateWords(): Iterable<string>;
    [Symbol.iterator](): Sequence<string>;
    /**
     * create an iterable sequence of the words in the dictionary.
     *
     * @param tapPreApplyRules -- optional function to be called before rules are applied to a word.
     *                            It is mostly used for monitoring progress.
     */
    seqAffWords(tapPreApplyRules?: (w: string) => any): Sequence<import("./aff").AffWord>;
    /**
     * @internal
     */
    seqWords(): Sequence<string>;
    /**
     * @internal
     */
    seqRootWords(): Sequence<string>;
    static createFromFiles(affFile: string, dicFile: string): Promise<IterableHunspellReader>;
}
